<?php
/**
 *
 * Cloudflare unmasked IP. An extension for the phpBB Forum Software package.
 *
 * @copyright (c) 2017, 3Di, http://3di.space/32/
 * @license GNU General Public License, version 2 (GPL-2.0)
 *
 */

namespace threedi\cloudflareunmaskedip\event;

/**
 * @ignore
 */
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Cloudflare unmasked IP Event listener.
 */
class main_listener implements EventSubscriberInterface
{
	static public function getSubscribedEvents()
	{
		return array(
			'core.session_ip_after'	=> 'unmask_cloudflare_ip',
		);
	}

	/**
	 * Request object
	 * @var \phpbb\request\request
	 */
	protected $request;

	/**
	 * Constructor
	 *
	 * @param	\phpbb\request\request		$request	Request object
	 */
	public function __construct(\phpbb\request\request $request)
	{
		$this->request = $request;
	}

	/**
	 * Event to alter user IP address
	 *
	 * @event core.session_ip_after
	 * @var	string	ip	REMOTE_ADDR
	 * @since 3.1.10-RC1
	 */
	public function unmask_cloudflare_ip($event)
	{
		$ip_check = $event['ip'];

		/**
		 * Normalizes user IPs when Cloudflare is running on the server.
		 *
		 * Ternary Operator improves performance.
		 * I can't use the Null Coalescing Operator (PHP7) due to BC with phpBB 3.1.x
		 */
		$ip_check = ($this->request->server('HTTP_CF_CONNECTING_IP') != '') ? htmlspecialchars_decode($this->request->server('HTTP_CF_CONNECTING_IP')) : htmlspecialchars_decode($this->request->server('REMOTE_ADDR'));

		$event['ip'] = (string) $ip_check;
	}
}
